package cn.com.ty.lift.system.user.service.impl;

import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.system.user.entity.Menu;
import cn.com.ty.lift.system.mapper.MenuMapper;
import cn.com.ty.lift.system.user.service.IMenuService;
import cn.com.ty.lift.system.user.tree.TreeUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author huangyuan
 * @date 2019-12-01
 * @description 菜单接口实现类
 */
@Service
public class MenuService implements IMenuService {

    @Autowired
    private MenuMapper menuMapper;

    @Override
    public List<Menu> getByRoleId(Long roleId) {
        return menuMapper.getByRoleId(roleId);
    }

    @Override
    public String menuToUrl(List<Menu> menuList) {
        //将菜单转化为菜单树
        List<Menu> menuTree = TreeUtil.listToTree(menuList, ApiConstants.ROOT_MENU_PARENT_ID);
        StringBuilder sb = new StringBuilder();
        //递归组合菜单路径
        menuTreeToUrl(menuTree, sb, "");
        return sb.toString();
    }

    /**
     * @description 菜单树转化为路径字符串
     * @date 2019/11/27 10:03 AM
     * @param menuTree 菜单树，
     * @param sb 路径StringBuilder对象
     * @param url 请求路径
     * @return
     */
    private void menuTreeToUrl(List<Menu> menuTree, StringBuilder sb, String url){
        if(menuTree != null && menuTree.size() > 0){
            for(Menu menu:menuTree){
                if(StringUtils.isNotBlank(menu.getUrl())){
                    url = url + menu.getUrl();
                }
                menuTreeToUrl(menu.getChildren(), sb, url);
            }
        }
        sb.append(url + ",");
    }
}
